@@ -5,19 +5,23 @@
 Build a combined news file from news fragments.
 """
 
-from __future__ import absolute_import, division, print_function
 
 import os
-import click
 import sys
 
 from datetime import date
 
-from ._settings import load_config_from_options, ConfigError
-from ._builder import find_fragments, split_fragments, render_fragments
-from ._project import get_version, get_project_name
-from ._writer import append_to_newsfile
+import click
+
+from ._builder import find_fragments, render_fragments, split_fragments
 from ._git import remove_files, stage_newsfile
+from ._project import get_project_name, get_version
+from ._settings import (
+    ConfigError,
+    config_option_help,
+    load_config_from_options,
+)
+from ._writer import append_to_newsfile
 
 
 def _get_date():
@@ -30,11 +34,31 @@ def _get_date():
     "draft",
     default=False,
     flag_value=True,
-    help="Render the news fragments, don't write to files, don't check versions.",
+    help=(
+        "Render the news fragments to standard output. "
+        "Don't write to files, don't check versions."
+    ),
+)
+@click.option(
+    "--config",
+    "config_file",
+    default=None,
+    metavar="FILE_PATH",
+    help=config_option_help,
+)
+@click.option(
+    "--dir",
+    "directory",
+    default=None,
+    metavar="PATH",
+    help="Build fragment in directory. Default to current directory.",
+)
+@click.option(
+    "--name",
+    "project_name",
+    default=None,
+    help="Pass a custom project name.",
 )
-@click.option("--config", "config_file", default=None, help="Configuration file name.")
-@click.option("--dir", "directory", default=None)
-@click.option("--name", "project_name", default=None)
 @click.option(
     "--version",
     "project_version",
@@ -58,6 +82,9 @@ def _main(
     project_date,
     answer_yes,
 ):
+    """
+    Build a combined news file from news fragment.
+    """
     try:
         return __main(
             draft,
@@ -115,19 +142,21 @@ def __main(
     )
 
     if project_version is None:
-        project_version = config.get('version')
+        project_version = config.get("version")
         if project_version is None:
             project_version = get_version(
                 os.path.join(base_directory, config["package_dir"]), config["package"]
             ).strip()
 
     if project_name is None:
-        project_name = config.get('name')
+        project_name = config.get("name")
         if not project_name:
             package = config.get("package")
             if package:
                 project_name = get_project_name(
-                    os.path.abspath(os.path.join(base_directory, config["package_dir"])),
+                    os.path.abspath(
+                        os.path.join(base_directory, config["package_dir"])
+                    ),
                     package,
                 )
             else:
@@ -141,14 +170,23 @@ def __main(
         top_line = config["title_format"].format(
             name=project_name, version=project_version, project_date=project_date
         )
+        render_title_with_fragments = False
+        render_title_separately = True
+    elif config["title_format"] is False:
+        # This is an odd check but since we support both "" and False with
+        # different effects we have to do something a bit abnormal here.
+        top_line = ""
+        render_title_separately = False
+        render_title_with_fragments = False
     else:
         top_line = ""
+        render_title_separately = False
+        render_title_with_fragments = True
 
     rendered = render_fragments(
         # The 0th underline is used for the top line
         template,
         config["issue_format"],
-        top_line,
         fragments,
         definitions,
         config["underlines"][1:],
@@ -156,22 +194,35 @@ def __main(
         {"name": project_name, "version": project_version, "date": project_date},
         top_underline=config["underlines"][0],
         all_bullets=config["all_bullets"],
+        render_title=render_title_with_fragments,
     )
 
+    if render_title_separately:
+        content = "\n".join(
+            [
+                top_line,
+                config["underlines"][0] * len(top_line),
+                rendered,
+            ]
+        )
+    else:
+        content = rendered
+
     if draft:
         click.echo(
             "Draft only -- nothing has been written.\n"
             "What is seen below is what would be written.\n",
             err=to_err,
         )
-        click.echo(rendered)
+        click.echo(content)
     else:
         click.echo("Writing to newsfile...", err=to_err)
         start_string = config["start_string"]
         news_file = config["filename"]
 
-        if config["single_file"]:
-            # When single_file is enabled, the news file name changes based on the version.
+        if config["single_file"] is False:
+            # The release notes for each version are stored in a separate file.
+            # The name of that file is generated based on the current version and project.
             news_file = news_file.format(
                 name=project_name, version=project_version, project_date=project_date
             )
@@ -181,7 +232,7 @@ def __main(
             news_file,
             start_string,
             top_line,
-            rendered,
+            content,
             single_file=config["single_file"],
         )
 
